@@ -226,7 +226,10 @@ class DataBufferDict(object):
 
     def extendleft(self, bufs):
         for chan, buf in bufs.items():
-            self.buffers[chan].extendleft(buf)
+            if chan in self.buffers:
+                self.buffers[chan].extendleft(buf)
+            else:
+                self.buffers[chan] = buf
 
     def extend(self, bufs):
         for chan, buf in bufs.items():
@@ -318,10 +321,6 @@ class DataStore(QtCore.QObject):
                 error = f"Unknown channel '{channel}'."
                 self.signal_channel_add.emit((channel, error))
                 raise UnknownChannelError(error)
-        elif list(nds.find_channels(channel).keys()) != [channel]:
-            error = f"Unknown channel '{channel}'."
-            self.signal_channel_add.emit((channel, error))
-            raise UnknownChannelError(error)
         self._channels[channel] += 1
         assert self._channels[channel] > 0
         self.signal_channel_add.emit((channel, None))
