@@ -43,8 +43,8 @@ def hold_over_nan(y):
     """
     nani = np.where(np.isnan(y))[0]
     if nani.size == y.size:
-        return np.zeros_like(y, dtype=np.float)
-    out = np.empty_like(y, dtype=np.float)
+        return np.zeros_like(y, dtype=float)
+    out = np.empty_like(y, dtype=float)
     out[:] = np.nan
     if nani.size == 0:
         return out
