@@ -100,7 +100,9 @@ class NDScope(*load_ui('scope.ui')):
         self.labelChannelCount.setToolTip("channel count")
         # the '1' add stretch to push the next label to the right side
         self.statusBar.addWidget(self.labelChannelCount, 1)
-        self.statusBar.addWidget(QtWidgets.QLabel(f"ndscope {__version__}"))
+        labelHome = QtWidgets.QLabel(f"<a href=https://git.ligo.org/cds/software/ndscope>ndscope {__version__}</a> (<a href=https://git.ligo.org/cds/software/ndscope/issues>report bug</a>)")
+        labelHome.setOpenExternalLinks(True)
+        self.statusBar.addWidget(labelHome)
         self.statusClearButton = QtWidgets.QPushButton("clear")
         # permanent widgets are added to the right side
         self.statusBar.addPermanentWidget(self.statusClearButton)
