@@ -244,6 +244,15 @@ def load_template(path):
 
     return template, ltype
 
+
+def template_extract_channels(template):
+    """Return the set of all channels listed in a template"""
+    channels = set()
+    for plot in template['plots']:
+        for channel_dict in plot['channels']:
+            channels.update(channel_dict.keys())
+    return channels
+
 ##########
 
 
